@@ -30,9 +30,11 @@
 #include <stdalign.h>
 #endif
 
-#if !defined(HAVE_ALIGNED_ALLOC) && defined(_MSC_VER) && _MSC_VER >= 1800
+#if defined(_MSC_VER) && _MSC_VER >= 1800
 #include <malloc.h>
+#ifndef HAVE_ALIGNED_ALLOC
 #define HAVE_ALIGNED_ALLOC 1
+#endif
 #define aligned_alloc(a, s) _aligned_malloc(s, a)
 #endif
 
