@@ -410,6 +410,10 @@ public:
 
 	typeref& operator=(value *chars);
 
+	typeref operator+(const char *str) const;
+
+	typeref operator+(const typeref& ptr) const;
+
 	const char *operator()(ssize_t offset) const;
 
 	void set(const char *str);
@@ -480,6 +484,8 @@ public:
 		return !(*this == bytes);
 	}
 
+	typeref operator+(const typeref& ptr) const;
+
 	void set(const uint8_t *str, size_t size);
 
 	void assign(value *bytes);
